/** \file
 * \brief GL Controls Class Initialization functions.
 *
 * See Copyright Notice in "iup.h"
 */
 
#ifndef __IUP_GLCONTROLS_H 
#define __IUP_GLCONTROLS_H


#ifdef __cplusplus
extern "C" {
#endif


Iclass* iupGLCanvasBoxNewClass(void);
Iclass* iupGLSubCanvasNewClass(void);
Iclass* iupGLLabelNewClass(void);
Iclass* iupGLSeparatorNewClass(void);
Iclass* iupGLButtonNewClass(void);
Iclass* iupGLToggleNewClass(void);
Iclass* iupGLLinkNewClass(void);
Iclass* iupGLProgressBarNewClass(void);
Iclass* iupGLValNewClass(void);
Iclass* iupGLFrameNewClass(void);
Iclass* iupGLExpanderNewClass(void);
Iclass* iupGLScrollBoxNewClass(void);
Iclass* iupGLSizeBoxNewClass(void);
Iclass* iupGLTextNewClass(void);


#ifdef __cplusplus
}
#endif

#endif
